﻿#region Using ステートメント

using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;

#endregion

namespace WpfFontSample
{
    /// <summary>
    /// メッセージテーブル
    /// </summary>
    /// <remarks>
    /// Windows Phone等のReachデバイスで、一度に大量の文章を表示するのは、速度的な
    /// 問題があるので、このサンプルでは文章を段落(Paragraph)ごとに区切ってデータを
    /// 格納している。
    /// 
    /// 開発効率を上げる為に、本来はこういったデータ分割処理はコンテント・パイプラインで
    /// 行うべき。
    /// 
    /// また、このソースファイル自体がWPFフォントプロセッサーの読み込みファイルとして
    /// 設定されているので(Font.spritefontの追加文字テキストファイル名)、
    /// このメッセージを変更する毎に自動的にコンテント・コンパイルしなおされるので
    /// メッセージとフォントのデータは常に同期するようになっている
    /// </remarks>
    static class MessageTable
    {
        public static Paragraph[] Messages = 
        {
            new Paragraph(MessageFontType.Title, "WPF フォントプロセッサー"),

            new Paragraph(
                "XNA付属のSpriteFontプロセッサーではGDI+で文字描画して\n" +
                "スプライトフォントを生成しています。\n"
                ),

            new Paragraph(
                "GDI+にはOpenTypeフォント未対応という問題があり、\n" +
                "『小塚ゴシック』を始めとした多くのOpenTypeフォントを\n" +
                "XNAで容易に使うことができませんでした。\n"
                ),

            new Paragraph(
                "そこで、このサンプルではGDI+の代わりにWPF文字描画を\n" +
                "使用したWPFフォントプロセッサーの機能を紹介します。\n"
                ),

            new Paragraph(
                "WPFフォントプロセッサーの特徴として、OpenTypeフォント\n" +
                "対応、文字処理の高速化、そしてWPFによる文字装飾があり\n" +
                "ます。\n"
                ),

            new Paragraph(
                "OpenTypeフォント対応は最大の特徴で、現在普及している\n" +
                "多くのOpenTypeフォントをXNAゲーム内でも簡単に使える\n" +
                "ようになりました。\n"
                ),

            new Paragraph(
                "そして、文字処理の高速化では大量の文字処理に特化した\n" +
                "アルゴリズム採用により、標準フォントプロセッサーに比べて\n" +
                "200倍以上の高速化を達成しています。\n"
                ),

            new Paragraph(
                "実測値として2,300文字を処理するのに3分20秒掛かっていた\n" +
                "のが、WPFフォントプロセッサーでは、1秒と掛からずにスプ\n" +
                "ライトフォントの生成をすることができます。\n"
                ),
            new Paragraph(
                "スプライトフォント生成処理が劇的に高速化したことにより、\n" +
                "コンテント・コンパイル時間を気にせずに手軽に文字数を\n" +
                "増やすことができるようになりました。そこで、フォントプロ\n" +
                "セッサーのパラメーターで、ひらがな、カタカナに加えてJIS\n" +
                "第1水準漢字(2,965字)等の文字を簡単に追加できるように\n" +
                "なっています。\n"
                ),
            new Paragraph(
                "最後に、WPFによる文字装飾ですが、WPFでは文字描画時に\n" +
                "多彩なブラシを始め、Geometryへ変換することでアウト\n" +
                "ライン描画等をすることができます。\n"
                ),
            new Paragraph(
                "WPFフォントプロセッサーでは、線形グラデーションブラシと\n" +
                "アウトライン描画に対応しています。"
                ),

            new Paragraph(MessageFontType.Gradient, "グラデーション文字描画♪"),
            new Paragraph(MessageFontType.Outline, "アウトライン文字描画♪"),

            new Paragraph(
                "WPFには、グラデーションやアウトライン描画以外にも、\n" +
                "自由に文字描画をカスタマイズができるようになっています。\n"
                ),
            new Paragraph(
                "WPFフォントプロセッサーの文字描画部分は仮想メソッドと\n" +
                "して定義されているので、WPFフォントプロセッサーのクラス\n" +
                "から派生したクラス内で独自の文字描画を実装するのが容易に\n" +
                "なっています。\n"
                ),
            new Paragraph(
                "このように、WPFフォントプロセッサーはXNAでの日本語の\n" +
                "扱いが格段に向上しただけでなく、様々な機能が追加されて\n" +
                "いるので、是非ご活用ください！！"
                )
        };

    }
}
